numerical
=========

Collection of mathematical utilities that are commonly used in other projects.

*   decimal functions
*   number predicates
*   number decorators
*   number strategies
*   common numeric functions
